<?php
/**
 * This code was generated by
 * ___ _ _ _ _ _    _ ____    ____ ____ _    ____ ____ _  _ ____ ____ ____ ___ __   __
 *  |  | | | | |    | |  | __ |  | |__| | __ | __ |___ |\ | |___ |__/ |__|  | |  | |__/
 *  |  |_|_| | |___ | |__|    |__| |  | |    |__] |___ | \| |___ |  \ |  |  | |__| |  \
 *
 * Twilio - Marketplace
 * This is the public Twilio REST API.
 *
 * NOTE: This class is auto generated by OpenAPI Generator.
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */

namespace Twilio\Rest\Marketplace\V1;

use Twilio\Options;
use Twilio\Values;

abstract class ModuleDataManagementOptions
{

    /**
     * @param string $moduleInfo 
     * @param string $description 
     * @param string $documentation 
     * @param string $policies 
     * @param string $support 
     * @param string $configuration 
     * @return UpdateModuleDataManagementOptions Options builder
     */
    public static function update(
        
        string $moduleInfo = Values::NONE,
        string $description = Values::NONE,
        string $documentation = Values::NONE,
        string $policies = Values::NONE,
        string $support = Values::NONE,
        string $configuration = Values::NONE

    ): UpdateModuleDataManagementOptions
    {
        return new UpdateModuleDataManagementOptions(
            $moduleInfo,
            $description,
            $documentation,
            $policies,
            $support,
            $configuration
        );
    }

}


class UpdateModuleDataManagementOptions extends Options
    {
    /**
     * @param string $moduleInfo 
     * @param string $description 
     * @param string $documentation 
     * @param string $policies 
     * @param string $support 
     * @param string $configuration 
     */
    public function __construct(
        
        string $moduleInfo = Values::NONE,
        string $description = Values::NONE,
        string $documentation = Values::NONE,
        string $policies = Values::NONE,
        string $support = Values::NONE,
        string $configuration = Values::NONE

    ) {
        $this->options['moduleInfo'] = $moduleInfo;
        $this->options['description'] = $description;
        $this->options['documentation'] = $documentation;
        $this->options['policies'] = $policies;
        $this->options['support'] = $support;
        $this->options['configuration'] = $configuration;
    }

    /**
     * 
     *
     * @param string $moduleInfo 
     * @return $this Fluent Builder
     */
    public function setModuleInfo(string $moduleInfo): self
    {
        $this->options['moduleInfo'] = $moduleInfo;
        return $this;
    }

    /**
     * 
     *
     * @param string $description 
     * @return $this Fluent Builder
     */
    public function setDescription(string $description): self
    {
        $this->options['description'] = $description;
        return $this;
    }

    /**
     * 
     *
     * @param string $documentation 
     * @return $this Fluent Builder
     */
    public function setDocumentation(string $documentation): self
    {
        $this->options['documentation'] = $documentation;
        return $this;
    }

    /**
     * 
     *
     * @param string $policies 
     * @return $this Fluent Builder
     */
    public function setPolicies(string $policies): self
    {
        $this->options['policies'] = $policies;
        return $this;
    }

    /**
     * 
     *
     * @param string $support 
     * @return $this Fluent Builder
     */
    public function setSupport(string $support): self
    {
        $this->options['support'] = $support;
        return $this;
    }

    /**
     * 
     *
     * @param string $configuration 
     * @return $this Fluent Builder
     */
    public function setConfiguration(string $configuration): self
    {
        $this->options['configuration'] = $configuration;
        return $this;
    }

    /**
     * Provide a friendly representation
     *
     * @return string Machine friendly representation
     */
    public function __toString(): string
    {
        $options = \http_build_query(Values::of($this->options), '', ' ');
        return '[Twilio.Marketplace.V1.UpdateModuleDataManagementOptions ' . $options . ']';
    }
}

